# coding: utf-8

# flake8: noqa
"""
    Vector Similarity Demo

    The test functionality and Query testing  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@hyper-space.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from hyperspace.models.any_of_update_by_query_query import AnyOfUpdateByQueryQuery
from hyperspace.models.auth_dto import AuthDto
from hyperspace.models.collection_collection_name_body import CollectionCollectionNameBody
from hyperspace.models.collection_name_dsl_search_body import CollectionNameDslSearchBody
from hyperspace.models.delete_by_query_request import DeleteByQueryRequest
from hyperspace.models.delete_by_query_response import DeleteByQueryResponse
from hyperspace.models.document import Document
from hyperspace.models.function_function_name_body import FunctionFunctionNameBody
from hyperspace.models.login_dto import LoginDto
from hyperspace.models.script import Script
from hyperspace.models.status_dto import StatusDto
from hyperspace.models.update_by_query import UpdateByQuery



# coding: utf-8

"""
    Vector Similarity Demo

    The test functionality and Query testing  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@hyper-space.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Script(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source': 'str',
        'lang': 'str',
        'params': 'dict(str, object)'
    }

    attribute_map = {
        'source': 'source',
        'lang': 'lang',
        'params': 'params'
    }

    def __init__(self, source=None, lang=None, params=None):  # noqa: E501
        """Script - a model defined in Swagger"""  # noqa: E501
        self._source = None
        self._lang = None
        self._params = None
        self.discriminator = None
        self.source = source
        if lang is not None:
            self.lang = lang
        if params is not None:
            self.params = params

    @property
    def source(self):
        """Gets the source of this Script.  # noqa: E501

        A string with the contents of the script.  # noqa: E501

        :return: The source of this Script.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this Script.

        A string with the contents of the script.  # noqa: E501

        :param source: The source of this Script.  # noqa: E501
        :type: str
        """
        if source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def lang(self):
        """Gets the lang of this Script.  # noqa: E501

        Scripting language.  # noqa: E501

        :return: The lang of this Script.  # noqa: E501
        :rtype: str
        """
        return self._lang

    @lang.setter
    def lang(self, lang):
        """Sets the lang of this Script.

        Scripting language.  # noqa: E501

        :param lang: The lang of this Script.  # noqa: E501
        :type: str
        """

        self._lang = lang

    @property
    def params(self):
        """Gets the params of this Script.  # noqa: E501

        Parameters passed to the script.  # noqa: E501

        :return: The params of this Script.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this Script.

        Parameters passed to the script.  # noqa: E501

        :param params: The params of this Script.  # noqa: E501
        :type: dict(str, object)
        """

        self._params = params

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Script, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Script):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Vector Similarity Demo

    The test functionality and Query testing  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@hyper-space.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "hyperspace-py"
VERSION = "1.1.380"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["certifi >= 14.05.14","six >= 1.10","python_dateutil >= 2.5.3","setuptools >= 21.0.0","urllib3 >= 1.15.1","msgpack"]

setup(
    name=NAME,
    version=VERSION,
    description="Vector Similarity Demo",
    author_email="support@hyper-space.io",
    url="",
    keywords=["Swagger", "Vector Similarity Demo"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    The test functionality and Query testing  # noqa: E501
    """
)
